@@ -1,6 +1,6 @@
 /**
  * perl-libxml-sax.h
- * $Id: perl-libxml-sax.h,v 1.1.1.1 2003/03/14 14:32:02 m_ilya Exp $
+ * $Id: perl-libxml-sax.h,v 1.2 2003/05/20 15:25:50 pajas Exp $
  */
 
 #ifndef __PERL_LIBXML_SAX_H__
@@ -18,15 +18,15 @@ extern "C" {
 
 /* has to be called in BOOT sequence */
 void
-PmmSAXInitialize();
+xpc_PmmSAXInitialize();
 
 void
-PmmSAXInitContext( xmlParserCtxtPtr ctxt, SV * parser );
+xpc_PmmSAXInitContext( xmlParserCtxtPtr ctxt, SV * parser );
 
 void 
-PmmSAXCloseContext( xmlParserCtxtPtr ctxt );
+xpc_PmmSAXCloseContext( xmlParserCtxtPtr ctxt );
 
 xmlSAXHandlerPtr
-PSaxGetHandler();
+xpc_PSaxGetHandler();
 
 #endif
